@@ -21,7 +21,7 @@ use XSLoader;
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(load getloadavg proc_loadavg uptime);
 
-our $VERSION = '0.25'; # TRIAL
+our $VERSION = '0.26'; # TRIAL
 
 XSLoader::load 'Sys::CpuLoad', $VERSION;
 
@@ -54,7 +54,7 @@ sub uptime {
 
     run3($UPTIME, \undef, \my $line);
     return undef if $? || !defined($line);
-    if ( $line =~ /(\d+\.\d+)\s*,?\s+(\d+\.\d+)\s*,?\s+(\d+\.\d+)\s*$/m )
+    if ( $line =~ /(\d+[,.]\d+)\s*,?\s+(\d+[,.]\d+)\s*,?\s+(\d+[,.]\d+)\s*$/m )
     {
         return ( $1, $2, $3 );
     }
@@ -96,7 +96,7 @@ Sys::CpuLoad - retrieve system load averages
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -198,12 +198,22 @@ Clinton Wong <clintdw@cpan.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Vincent Lefèvre
+=for stopwords Slaven Rezić Vincent Lefèvre
+
+=over 4
+
+=item *
+
+Slaven Rezić <slaven@rezic.de>
+
+=item *
 
 Vincent Lefèvre <vincent@vinc17.net>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 1999-2002, 2020 by Clinton Wong <clintdw@cpan.org>.
